@@ -26,7 +26,7 @@ class OpenApiSpecDiff(object):
 
     def parse_spec(self, spec_path):
         # try:
-        spec = ResolvingParser(spec_path, backend='openapi-spec-validator').specification
+        spec = ResolvingParser(spec_path).specification
         # except:
         #     spec = ResolvingParser(spec_path, backend='swagger-spec-validator').specification
         return self.scan_input_spec(spec)
@@ -72,6 +72,10 @@ class OpenApiSpecDiff(object):
             for key, info in body.get("properties").items():
                 data[key], required_params = self._process_nested_obj(info, key)
                 payload = data
+            for i in body.get("allOf",[]):
+                for key, info in i.get("properties").items():
+                    data[key], required_params = self._process_nested_obj(info, key)
+                    payload = data
         elif type == "array":
             payload = []
             data, required_params = self._process_nested_obj(body.get("items"), None)
@@ -84,11 +88,11 @@ class OpenApiSpecDiff(object):
         params = []
         for k, v in reqbody.get("content").items():
             payload, required_params = self._process_nested_obj(v["schema"], None)
-            #print(payload, required_params)
             if isinstance(payload, list):
                 for each in payload:
+                    params.append([])
                     for param, info in each.items():
-                        params.append({'in': 'body', "name": param, "value": info, "required": required_params})
+                        params[0].append({'in': 'body', "name": param, "value": info, "required": required_params})
             elif isinstance(payload, dict):
                 for param, info in payload.items():
                     params.append({'in': 'body', "name": param, "value": info, "required": required_params})
@@ -125,6 +129,7 @@ class OpenApiSpecDiff(object):
         for api, api_info in input_spec["paths"].items():
             for method, method_info in api_info.items():
                 to_replace = input_spec["paths"][api][method].get("parameters", [])
+                # print(api, input_spec["paths"][api][method]["parameters"], "?????", "\n\n")
                 if "requestBody" in method_info:
                     #print(api, method, method_info)
                     to_replace += self._process_reqbody(method_info["requestBody"])
@@ -144,6 +149,7 @@ class OpenApiSpecDiff(object):
                     #                                 if _ not in to_replace:
                     #                                     to_replace.append(_)
                     #                 input_spec["paths"][api][method]["parameters"] = to_replace
+
                     input_spec["paths"][api][method]["parameters"] = to_replace
                     # print("replacing reqbody"+str(input_spec["paths"][api][method]["parameters"]))
                     # print(api, method)
